# -*- rpm-spec -*-


%define with_guestfs               0
%define stable_defaults            0
%define askpass_package            "openssh-askpass"
%define qemu_user                  "qemu"
%define libvirt_packages           "libvirt-daemon-kvm,libvirt-daemon-config-network"
%define preferred_distros          "fedora,rhel"
%define kvm_packages               "qemu-system-x86"

%if 0%{?rhel}
%define preferred_distros          "rhel,fedora"
%define kvm_packages               "qemu-kvm"
%define stable_defaults            1
%endif


# End local config


%define _version 1.0.1
%define _release 4


# This macro is used for the continuous automated builds. It just
# allows an extra fragment based on the timestamp to be appended
# to the release. This distinguishes automated builds, from formal
# Fedora RPM builds
%define _extra_release %{?dist:%{dist}}%{?extra_release:%{extra_release}}

Name: virt-manager
Version: %{_version}
Release: %{_release}%{_extra_release}
%define verrel %{version}-%{release}

Summary: Virtual Machine Manager
Group: Applications/Emulators
License: GPLv2+
URL: http://virt-manager.org/
Source0: http://virt-manager.org/download/sources/%{name}/%{name}-%{version}.tar.gz

# gfxdetails: Show port number for active autoport VM (bz #1081614)
Patch0001: 0001-gfxdetails-Show-port-number-for-active-autoport-VM-b.patch
# connection: Hook into domain balloon event (bz #1081424)
Patch0002: 0002-connection-Hook-into-domain-balloon-event-bz-1081424.patch
# details: Fix showing vcpus values in 'customize' dialog (bz #1083903)
Patch0003: 0003-details-Fix-showing-vcpus-values-in-customize-dialog.patch
# details: Fix changing graphics type (bz #1083903)
Patch0004: 0004-details-Fix-changing-graphics-type-bz-1083903.patch
# createpool: Clarify iscsi IQN fields (bz #1084011)
Patch0005: 0005-createpool-Clarify-iscsi-IQN-fields-bz-1084011.patch
# More fixes for errors on libvirtd disconnect (bz #1069351)
Patch0006: 0006-error-Don-t-log-redundant-details-bits.patch
Patch0007: 0007-engine-More-work-to-fix-cascading-error-dialogs.patch
# filesystem: Fix target validation when editing device (bz #1089422)
Patch0008: 0008-filesystem-Fix-target-validation-when-editing-device.patch
# details: Explicit warn that 'format' doesn't change image format (bz
# #1089457)
Patch0009: 0009-details-Explicit-warn-that-format-doesn-t-change-ima.patch
# snapshots: Fix screenshot with qxl+spice (bz #1089780)
Patch0010: 0010-snapshots-Fix-screenshot-with-qxl-spice-bz-1089780.patch
# Fix using storage when the directory name contains whitespace (bz
# #1091384)
Patch0011: 0011-Fix-using-storage-when-the-directory-name-contains-w.patch
# packageutils: Fix install when one package is already installed (bz
# #1090181)
Patch0012: 0012-packageutils-Fix-install-when-one-package-is-already.patch
# Fix error reporting when checking libvirt version at conn startup (bz
# #1074120)
Patch0013: 0013-connection-Report-error-if-things-fall-over-during-c.patch
# Fix error reporting from delete dialog (bz #1092739)
Patch0014: 0014-engine-Show-error-if-launching-delete-dialog-fails.patch
Patch0015: 0015-connection-Call-path_exists-before-getting-storage-v.patch
# Fix ubuntu video default (bz #1129803)
Patch0016: 0016-Custom-F20-fix-for-ubuntu-vmvga-default-bug-1129803.patch
BuildArch: noarch


Requires: virt-manager-common = %{verrel}
Requires: pygobject3
Requires: gtk3
Requires: libvirt-glib >= 0.0.9
Requires: libxml2-python
Requires: vte3
Requires: dconf
Requires: dbus-x11

# For console widget
Requires: gtk-vnc2
Requires: spice-gtk3


BuildRequires: intltool
BuildRequires: /usr/bin/pod2man


%description
Virtual Machine Manager provides a graphical tool for administering virtual
machines for KVM, Xen, and LXC. Start, stop, add or remove virtual devices,
connect to a graphical or serial console, and see resource usage statistics
for existing VMs on local or remote machines. Uses libvirt as the backend
management API.


%package common
Summary: Common files used by the different Virtual Machine Manager interfaces
Group: Applications/Emulators

# This version not strictly required: virt-manager should work with older,
# however varying amounts of functionality will not be enabled.
Requires: libvirt-python >= 0.7.0
Requires: libxml2-python
Requires: python-urlgrabber
Requires: python-ipaddr

%description common
Common files used by the different virt-manager interfaces, as well as
virt-install related tools.


%package -n virt-install
Summary: Utilities for installing virtual machines

Requires: virt-manager-common = %{verrel}

Provides: virt-install
Provides: virt-clone
Provides: virt-image
Provides: virt-convert
Provides: virt-xml
Obsoletes: python-virtinst

%description -n virt-install
Package includes several command line utilities, including virt-install
(build and install new VMs) and virt-clone (clone an existing virtual
machine).


%prep
%setup -q

# gfxdetails: Show port number for active autoport VM (bz #1081614)
%patch0001 -p1
# connection: Hook into domain balloon event (bz #1081424)
%patch0002 -p1
# details: Fix showing vcpus values in 'customize' dialog (bz #1083903)
%patch0003 -p1
# details: Fix changing graphics type (bz #1083903)
%patch0004 -p1
# createpool: Clarify iscsi IQN fields (bz #1084011)
%patch0005 -p1
# More fixes for errors on libvirtd disconnect (bz #1069351)
%patch0006 -p1
%patch0007 -p1
# filesystem: Fix target validation when editing device (bz #1089422)
%patch0008 -p1
# details: Explicit warn that 'format' doesn't change image format (bz
# #1089457)
%patch0009 -p1
# snapshots: Fix screenshot with qxl+spice (bz #1089780)
%patch0010 -p1
# Fix using storage when the directory name contains whitespace (bz
# #1091384)
%patch0011 -p1
# packageutils: Fix install when one package is already installed (bz
# #1090181)
%patch0012 -p1
# Fix error reporting when checking libvirt version at conn startup (bz
# #1074120)
%patch0013 -p1
# Fix error reporting from delete dialog (bz #1092739)
%patch0014 -p1
%patch0015 -p1
# Fix ubuntu video default (bz #1129803)
%patch0016 -p1

%build
%if %{qemu_user}
%define _qemu_user --qemu-user=%{qemu_user}
%endif

%if %{kvm_packages}
%define _kvm_packages --kvm-package-names=%{kvm_packages}
%endif

%if %{preferred_distros}
%define _preferred_distros --preferred-distros=%{preferred_distros}
%endif

%if %{libvirt_packages}
%define _libvirt_packages --libvirt-package-names=%{libvirt_packages}
%endif

%if %{askpass_package}
%define _askpass_package --askpass-package-names=%{askpass_package}
%endif

%if %{stable_defaults}
%define _stable_defaults --stable-defaults
%endif

python setup.py configure \
    --pkgversion="%{version}" \
    %{?_qemu_user} \
    %{?_kvm_packages} \
    %{?_libvirt_packages} \
    %{?_askpass_package} \
    %{?_preferred_distros} \
    %{?_stable_defaults}


%install
python setup.py install -O1 --root=$RPM_BUILD_ROOT

%find_lang %{name}


%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
/usr/bin/update-desktop-database &> /dev/null || :


%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
fi
/usr/bin/update-desktop-database &> /dev/null || :


%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
/usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :


%files
%doc README COPYING NEWS
%{_bindir}/%{name}

%{_mandir}/man1/%{name}.1*

%{_datadir}/%{name}/ui/*.ui
%{_datadir}/%{name}/virt-manager
%{_datadir}/%{name}/virtManager

%{_datadir}/%{name}/icons
%{_datadir}/icons/hicolor/*/apps/*

%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/glib-2.0/schemas/org.virt-manager.virt-manager.gschema.xml


%files common -f %{name}.lang
%dir %{_datadir}/%{name}

%{_datadir}/%{name}/virtcli
%{_datadir}/%{name}/virtconv
%{_datadir}/%{name}/virtinst


%files -n virt-install
%{_mandir}/man1/virt-install.1*
%{_mandir}/man1/virt-clone.1*
%{_mandir}/man1/virt-convert.1*
%{_mandir}/man1/virt-xml.1*
%{_mandir}/man1/virt-image.1*
%{_mandir}/man5/virt-image.5*

%{_datadir}/%{name}/virt-install
%{_datadir}/%{name}/virt-clone
%{_datadir}/%{name}/virt-image
%{_datadir}/%{name}/virt-convert
%{_datadir}/%{name}/virt-xml

%{_bindir}/virt-install
%{_bindir}/virt-clone
%{_bindir}/virt-image
%{_bindir}/virt-convert
%{_bindir}/virt-xml


%changelog
* Mon Sep 08 2014 Cole Robinson <crobinso@redhat.com> - 1.0.1-4
- Fix error reporting when checking libvirt version at conn startup (bz
  #1074120)
- Fix error reporting from delete dialog (bz #1092739)
- Fix ubuntu video default (bz #1129803)

* Tue Apr 29 2014 Cole Robinson <crobinso@redhat.com> - 1.0.1-3
- filesystem: Fix target validation when editing device (bz #1089422)
- details: Explicit warn that 'format' doesn't change image format (bz
  #1089457)
- snapshots: Fix screenshot with qxl+spice (bz #1089780)
- Fix using storage when the directory name contains whitespace (bz #1091384)
- packageutils: Fix install when one package is already installed (bz
  #1090181)

* Wed Apr 16 2014 Cole Robinson <crobinso@redhat.com> - 1.0.1-2
- gfxdetails: Show port number for active autoport VM (bz #1081614)
- connection: Hook into domain balloon event (bz #1081424)
- details: Fix showing vcpus values in 'customize' dialog (bz #1083903)
- details: Fix changing graphics type (bz #1083903)
- createpool: Clarify iscsi IQN fields (bz #1084011)
- More fixes for errors on libvirtd disconnect (bz #1069351)

* Sat Mar 22 2014 Cole Robinson <crobinso@redhat.com> - 1.0.1-1
- Rebased to version 1.0.1
- virt-install/virt-xml: New --memorybacking option (Chen Hanxiao)
- virt-install/virt-xml: New --memtune option (Chen Hanxiao)
- virt-manager: UI for LXC <idmap> (Chen Hanxiao)
- virt-manager: gsettings key to disable keygrab (Kjö Hansi Glaz)
- virt-manager: Show domain state reason in the UI (Giuseppe Scrivano)
- Fix a number of bugs found since the 1.0.0 release
- Fix specifying emulator when switching connections (bz #1075444)
- Allow changing network device source for a running VM (bz #1078854)

* Mon Mar 10 2014 Cole Robinson <crobinso@redhat.com> - 1.0.0-6
- connection: Handle errors when deregistering events on close (bz #1069351)

* Fri Mar 07 2014 Cole Robinson <crobinso@redhat.com> - 1.0.0-5
- addhardware: Fix adding disk through 'customize' dialog (bz #1073808)

* Thu Mar 06 2014 Cole Robinson <crobinso@redhat.com> - 1.0.0-4
- virt-convert: better error if unar is not installed
- details: Fix fallback if fetching CPU models fails (bz #1072704)
- fsdetails: Fix adding a filesystem device (bz #1073067)
- virt-install: Fix --location iso again, and test it (bz #1071513)
- Handle libvirt generating invalid volume XML (bz #1072770)

* Fri Feb 28 2014 Cole Robinson <crobinso@redhat.com> - 1.0.0-3
- Fix creating storage paths if directory is all digits (bz #1069351)
- Properly close connection if tick fails (bz #1069351)
- virt-manager: Handle unrefreshed storage pools (bz #1070883)
- Fix unsetting 'auto resize' console property

* Tue Feb 18 2014 Cole Robinson <crobinso@redhat.com> - 1.0.0-2
- Fix open connection->lxc
- Fix issues creating ppc64 guests
- Fix generating disk targets from customize->addhw

* Fri Feb 14 2014 Cole Robinson <crobinso@redhat.com> - 1.0.0-1
- Rebased to version 1.0.0
- New tool virt-xml: Edit libvirt XML in one shot from the command line
- Improved defaults: qcow2, USB2, host CPU model, guest agent channel
- Introspect command line options like --disk=? or --network=help

* Sun Nov 10 2013 Cole Robinson <crobinso@redhat.com> - 0.10.0-5.git1ffcc0cc
- Fix vcpu vs. maxvcpu UI (bz #1016318)
- Fix app startup when run as root (bz #1016435)
- Release serial console when details window is closed (bz #1016445)
- Clarify snapshot VM state UI (bz #1016604)
- Fix adding qemu-guest-agent by default (bz #1016613)
- Fix first run app install (bz #1016825)
- Fix error reporting if initrd fetch fails (bz #1017419)
- Fix error reporting if app is run with no DISPLAY (bz #1021482)
- Fix usage of install media in /home/crobinso (bz #1025355)

* Sun Oct 06 2013 Cole Robinson <crobinso@redhat.com> - 0.10.0-4.git79196cdf
- Fix cdrom ordering if added via 'customize' (bz #905439)
- Default to spice/qxl for virt-install (bz #911734)
- Fill in cache and io values for new VMs (bz #967643)
- Add dep on dconf (bz #1012884)

* Tue Sep 24 2013 Cole Robinson <crobinso@redhat.com> - 0.10.0-3.gita2e52067
- Sync with git
- Don't try to launch multiple ssh askpass dialogs at once (bz #811346)
- Fix confusion when multiple progress dialogs are run (bz #1003101)
- Fix error adding macvtap nic (bz #1006324)
- Add an appdata file (bz #1011120)
- virt-install: fix nfs:// style URLs (bz #1011177)
- Fix spice with TLS (bz #904295)
- Reduce impact of memory leak (bz #972371)
- Fix parsing rawhide .treeinfo (bz #989162)

* Wed Aug 21 2013 Cole Robinson <crobinso@redhat.com> 0.10.0-2.git948b5359
- Update to git snapshot for ARM support

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.10.0-1.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jun 19 2013 Cole Robinson <crobinso@redhat.com> - 0.10.0-1
- Rebased to version 0.10.0
- Fix screenshots (bz #969410)
- Add Fedora 19 osdict option (bz #950230)
- Fix loading libguestfs OS icons (bz #905238)
- Make packagekit search cancellable (bz #973777)
- Fix freeze on guest shutdown if serial console connected (bz #967968)

* Mon May 27 2013 Cole Robinson <crobinso@redhat.com> - 0.10.0-0.5.gitde1695b2
- Fix default graphics, should be spice+qxl (bz #965864)
- Check for libvirt default network package on first run (bz #950329)
- Fix changing VM cirrus->QXL (bz #928882)

* Wed May 15 2013 Cole Robinson <crobinso@redhat.com> - 0.10.0-0.4.gitb68faac8
- Drop bogus packagekit check for avahi-tools (bz #963472)

* Wed May 15 2013 Cole Robinson <crobinso@redhat.com> - 0.10.0-0.3.gitb68faac8
- Fix error creating QEMU guests (bz #962569)

* Thu May 09 2013 Cole Robinson <crobinso@redhat.com> - 0.10.0-0.2.gitb68faac8
- Fix dep on vte3 (bz #958945)
- Fix dep on virt-manager-common (bz #958730)
- Fix crash when installing from ISO media (bz #958641)
- Fix poor error reporting with unknown CLI option (bz #958730)

* Mon Apr 29 2013 Cole Robinson <crobinso@redhat.com> - 0.10.0-0.1.gitd3f9bc8e
- Update to git snapshot for next release

* Mon Apr 01 2013 Cole Robinson <crobinso@redhat.com> - 0.9.5-1
- Rebased to version 0.9.5
- Enable adding virtio-scsi disks (Chen Hanxiao) (bz 887584)
- Support security auto-relabel setting (Martin Kletzander)
- Support disk iotune settings (David Shane Holden)
- Support 'reset' as a reboot option (John Doyle)
- Don't pull in non-native qemu packages on first run (bz 924469)
- Don't create LVM volumes with alloc=0, it doesn't work (bz 872162)
- Fix storage browser hang on KDE (bz 880781)
- Fix package installation on KDE (bz 882024)

* Fri Mar 01 2013 Cole Robinson <crobinso@redhat.com> - 0.9.4-5
- Add explicit dep on pod2man (bz #914562)

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.4-4.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Mon Dec 17 2012 Cole Robinson <crobinso@redhat.com> - 0.9.4-4
- Use correct KVM package names on first run (bz #873878)
- network: fix parsing ip blocks with prefix= (bz #872814)
- Don't recommend all of libvirt, just the kvm bits (bz #872246)

* Tue Oct 30 2012 Cole Robinson <crobinso@redhat.com> - 0.9.4-3
- Fix first run packagekit interaction (bz #870851)
- Fix another backtrace if guest is pmsuspended (bz #871237)

* Wed Oct 24 2012 Cole Robinson <crobinso@redhat.com> - 0.9.4-2
- Fix KVM package install on app first run
- Fix listing domain with 'suspended' state (bz #850954)
- Fix 'browse local' behavior when choosing directory (bz #855335)
- Fix libgnome-keyring dep (bz #811921)

* Sun Jul 29 2012 Cole Robinson <crobinso@redhat.com> - 0.9.4-1
- Rebased to version 0.9.4
- Fix VNC keygrab issues (bz 840240)

* Sun Jul 22 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.3-1.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Jul 09 2012 Cole Robinson <crobinso@redhat.com> - 0.9.3-1
- Rebased to version 0.9.3
- Convert to gtkbuilder: UI can now be editted with modern glade tool
- virt-manager no longer runs on RHEL5, but can manage a remote RHEL5
  host
- Option to configure spapr net and disk devices for pseries (Li Zhang)
- Offer to install openssh-askpass if we need it (bz 754484)
- Don't leave defunct SSH processes around (bz 757892)
- Offer to start libvirtd after install (bz 791152)
- Fix crash when deleting storage volumes (bz 805950)
- Show serial device PTY path again (bz 811760)
- Fix possible crash when rebooting fails (bz 813119)
- Offer to discard state if restore fails (bz 837236)

* Wed Jun 06 2012 Cole Robinson <crobinso@redhat.com> - 0.9.1-4
- Fix connecting to console with specific listen address
- Fix regression that dropped spice dependency (bz 819270)

* Wed Apr 25 2012 Cole Robinson <crobinso@redhat.com> - 0.9.1-3
- Actually make spice the default (bz 757874)
- Only depend on spice on arch it is available (bz 811030)
- Depend on libgnome-keyring (bz 811921)

* Mon Feb 13 2012 Cole Robinson <crobinso@redhat.com> - 0.9.1-2
- Fix error reporting for failed remote connections (bz 787011)
- Fix setting window title when VNC mouse is grabbed (bz 788443)
- Advertise VDI format in disk details (bz 761300)
- Don't let an unavailable host hang the app (bz 766769)
- Don't overwrite existing create dialog when reshowing (bz 754152)
- Improve tooltip for 'force console shortcuts' (bz 788448)

* Wed Feb 01 2012 Cole Robinson <crobinso@redhat.com> - 0.9.1-1
- Rebased to version 0.9.1
- Support for adding usb redirection devices (Marc-André Lureau)
- Option to switch usb controller to support usb2.0 (Marc-André Lureau)
- Option to specify machine type for non-x86 guests (Li Zhang)
- Support for filesystem device type and write policy (Deepak C Shetty)
- Many bug fixes!

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.0-8.1
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Oct 28 2011 Cole Robinson <crobinso@redhat.com> - 0.9.0-8
- Fix crashes when deleting a VM (bz 749263)

* Tue Sep 27 2011 Cole Robinson <crobinso@redhat.com> - 0.9.0-7
- Fix 'Resize to VM' graphical option (bz 738806)
- Fix deleting guest with managed save data
- Fix error when adding default storage
- Don't flush XML cache on every tick
- Use labels for non-editable network info fields (bz 738751)
- Properly update icon cache (bz 733836)

* Tue Aug 02 2011 Cole Robinson <crobinso@redhat.com> - 0.9.0-6
- Fix python-newt_syrup dep

* Mon Aug 01 2011 Cole Robinson <crobinso@redhat.com> - 0.9.0-5
- Don't have a hard dep on libguestfs (bz 726364)
- Depend on needed python-newt_syrup version

* Thu Jul 28 2011 Cole Robinson <crobinso@redhat.com> - 0.9.0-4
- Fix typo that broke net stats reporting

* Wed Jul 27 2011 Cole Robinson <crobinso@redhat.com> - 0.9.0-3
- Add BuildRequires: GConf2 to fix pre scriplet error

* Tue Jul 26 2011 Cole Robinson <crobinso@redhat.com> - 0.9.0-2
- Fix virtinst dep

* Tue Jul 26 2011 Cole Robinson <crobinso@redhat.com> - 0.9.0-1.fc17
- Rebased to version 0.9.0
- Use a hiding toolbar for fullscreen mode
- Use libguestfs to show guest packagelist and more (Richard W.M. Jones)
- Basic 'New VM' wizard support for LXC guests
- Remote serial console access (with latest libvirt)
- Remote URL guest installs (with latest libvirt)
- Add Hardware: Support <filesystem> devices
- Add Hardware: Support <smartcard> devices (Marc-André Lureau)
- Enable direct interface selection for qemu/kvm (Gerhard Stenzel)
- Allow viewing and changing disk serial number

* Thu Apr 28 2011 Cole Robinson <crobinso@redhat.com> - 0.8.7-5.fc16
- Stop netcf errors from flooding logs (bz 676920)
- Bump default mem for new guests to 1GB so F15 installs work (bz
  700480)

* Tue Apr 19 2011 Cole Robinson <crobinso@redhat.com> - 0.8.7-4.fc16
- Fix spice RPM dependency (bz 697729)

* Thu Apr 07 2011 Cole Robinson <crobinso@redhat.com> - 0.8.7-3.fc16
- Fix broken cs.po which crashed gettext
- Fix offline attach fallback if hotplug fails
- Offer to attach spicevmc if switching to spice

* Thu Mar 31 2011 Cole Robinson <crobinso@redhat.com> - 0.8.7-2.fc16
- Fix using spice as default graphics type
- Fix lockup as non-root (bz 692570)

* Mon Mar 28 2011 Cole Robinson <crobinso@redhat.com> - 0.8.7-1.fc16
- Rebased to version 0.8.7
- Allow renaming an offline VM
- Spice password support (Marc-André Lureau)
- Allow editting NIC <virtualport> settings (Gerhard Stenzel)
- Allow enabling/disabling individual CPU features
- Allow easily changing graphics type between VNC/SPICE for existing VM
- Allow easily changing network source device for existing VM

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Feb  2 2011 Cole Robinson <crobinso@redhat.com> - 0.8.6-1.fc15
- Update to 0.8.6
- SPICE support (requires spice-gtk) (Marc-André Lureau)
- Option to configure CPU model
- Option to configure CPU topology
- Save and migration cancellation (Wen Congyang)
- Save and migration progress reporting
- Option to enable bios boot menu
- Option to configure direct kernel/initrd boot

* Wed Aug 25 2010 Cole Robinson <crobinso@redhat.com> - 0.8.5-1.fc15
- Update to 0.8.5
- Improved save/restore support
- Option to view and change disk cache mode
- Configurable VNC keygrab sequence (Michal Novotny)

* Mon Aug  2 2010 David Malcolm <dmalcolm@redhat.com> - 0.8.4-3.fc15
- fix python 2.7 incompatibility (bz 620216)

* Thu May 27 2010 Cole Robinson <crobinso@redhat.com> - 0.8.4-2.fc14
- Only close connection on specific remote errors
- Fix weird border in manager UI (bz 583728)
- Fix broken icons
- Cancel post-install reboot if VM is forced off
- Fix traceback if customizing a livecd install (bz 583712)
- Add pool refresh button
- Properly autodetect VNC keymap (bz 586201)
- Fix traceback when reconnecting to remote VNC console (bz 588254)
- Fix remote VNC connection with zsh as default shell

* Wed Mar 24 2010 Cole Robinson <crobinso@redhat.com> - 0.8.4-1.fc14
- Update to version 0.8.4
- 'Import' install option, to create a VM around an existing OS image
- Support multiple boot devices and boot order
- Watchdog device support
- Enable setting a human readable VM description.
- Option to manually specifying a bridge name, if bridge isn't detected

* Mon Mar 22 2010 Cole Robinson <crobinso@redhat.com> - 0.8.3-2.fc14
- Fix using a manual 'default' pool (bz 557020)
- Don't force grab focus when app is run (bz 548430)
- Check packagekit for KVM and libvirtd (bz 513494)
- Fake a reboot implementation if libvirt doesn't support it (bz 532216)
- Mark some strings as translatable (bz 572645)

* Mon Feb  8 2010 Cole Robinson <crobinso@redhat.com> - 0.8.3-1.fc13
- Update to 0.8.3 release
- Manage network interfaces: start, stop, view, provision bridges, bonds, etc.
- Option to 'customize VM before install'.

* Tue Jan 12 2010 Cole Robinson <crobinso@redhat.com> - 0.8.2-2.fc13
- Build with actual upstream tarball (not manually built dist)

* Mon Dec 14 2009 Cole Robinson <crobinso@redhat.com> - 0.8.2-1.fc13
- Update to 0.8.2 release
- Fix first virt-manager run on a new install
- Enable floppy media eject/connect

* Wed Dec 09 2009 Cole Robinson <crobinso@redhat.com> - 0.8.1-3.fc13
- Select manager row on right click, regressed with 0.8.1

* Sat Dec  5 2009 Cole Robinson <crobinso@redhat.com> - 0.8.1-2.fc13
- Set proper version Requires: for python-virtinst

* Thu Dec  3 2009 Cole Robinson <crobinso@redhat.com> - 0.8.1-1.fc13
- Update to release 0.8.1
- VM Migration wizard, exposing various migration options
- Enumerate CDROM and bridge devices on remote connections
- Support storage pool source enumeration for LVM, NFS, and SCSI

* Mon Oct 05 2009 Cole Robinson <crobinso@redhat.com> - 0.8.0-8.fc13
- Don't allow creating a volume without a name (bz 526111)
- Don't allow volume allocation > capacity (bz 526077)
- Add tooltips for toolbar buttons (bz 524083)

* Mon Oct 05 2009 Cole Robinson <crobinso@redhat.com> - 0.8.0-7.fc13
- More translations (bz 493795)

* Tue Sep 29 2009 Cole Robinson <crobinso@redhat.com> - 0.8.0-6.fc13
- Fix VCPU hotplug
- Remove access to outdated docs (bz 522823, bz 524805)
- Update VM state text in manager view (bz 526182)
- Update translations (bz 493795)

* Thu Sep 24 2009 Cole Robinson <crobinso@redhat.com> - 0.8.0-5.fc12
- Refresh host disk space in create wizard (bz 502777)
- Offer to fix disk permission issues (bz 517379)

* Thu Sep 17 2009 Cole Robinson <crobinso@redhat.com> - 0.8.0-4.fc12
- Don't close libvirt connection for non-fatal errors (bz 522168)
- Manager UI tweaks
- Generate better errors if disk/net stats polling fails

* Mon Sep 14 2009 Cole Robinson <crobinso@redhat.com> - 0.8.0-3.fc12
- Fix disk XML mangling via connect/eject cdrom (bz 516116)
- Fix delete button sensitivity (bz 518536)
- Fix populating text box from storage browser in 'New VM' (bz 517263)
- Fix a traceback in an 'Add Hardware' error path (bz 517286)

* Thu Aug 13 2009 Daniel P. Berrange <berrange@redhat.com> - 0.8.0-2.fc12
- Remove obsolete dep on policykit agent

* Tue Jul 28 2009 Cole Robinson <crobinso@redhat.com> - 0.8.0-1.fc12
- Update to release 0.8.0
- New 'Clone VM' Wizard
- Improved UI, including an overhaul of the main 'manager' view
- System tray icon for easy VM access (start, stop, view console/details)
- Wizard for adding serial, parallel, and video devices to existing VMs.

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.7.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu May 21 2009 Mark McLoughlin <markmc@redhat.com> - 0.7.0-5.fc12
- Fix 'opertaing' typo in 'New VM' dialog (#495128)
- Allow details window to resize again (#491683)
- Handle collecting username for vnc authentication (#499589)
- Actually handle arch config when creating a VM (#499145)
- Log libvirt capabilities at startup to aid debugging (#500337)

* Tue Apr 14 2009 Cole Robinson <crobinso@redhat.com> - 0.7.0-4.fc11
- More translation updates

* Thu Apr 09 2009 Cole Robinson <crobinso@redhat.com> - 0.7.0-3.fc11
- Fix incorrect max vcpu setting in New VM wizard (bz 490466)
- Fix some OK/Cancel button ordering issues (bz 490207)
- Use openAuth when duplicating a connection when deleting a VM
- Updated translations (bz 493795)

* Mon Mar 23 2009 Cole Robinson <crobinso@redhat.com> - 0.7.0-2.fc11
- Back compat fixes for connecting to older xen installations (bz 489885)
- Don't show harmless NoneType error when launching new VM details window

* Tue Mar 10 2009 Cole Robinson <crobinso@redhat.com> - 0.7.0-1.fc11
- Update to release 0.7.0
- Redesigned 'New Virtual Machine' wizard
- Option to remove storage when deleting a virtual machine.
- File browser for libvirt storage pools and volumes
- Physical device assignment (PCI, USB) for existing virtual machines.

* Wed Mar  4 2009 Cole Robinson <crobinso@redhat.com> - 0.6.1-4.fc11
- Update polish translation (bz 263301)
- Fix sending ctrl-alt-del to guest
- Fix cpu + mem stats options to remember preference.

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Feb  9 2009 Cole Robinson <crobinso@redhat.com> - 0.6.1-2
- Kill off consolehelper (PolicyKit is sufficient)

* Mon Jan 26 2009 Cole Robinson <crobinso@redhat.com> - 0.6.1-1
- Update to 0.6.1 release
- Disk and Network VM stats reporting
- VM Migration support
- Support adding sound devices to existing VMs
- Allow specifying device model when adding a network device to an existing VM

* Tue Jan 20 2009 Mark McLoughlin <markmc@redhat.com> - 0.6.0-7
- Add patch to ignore fix crash on force-poweroff with serial console (#470548)

* Thu Dec 04 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 0.6.0-6
- Rebuild for Python 2.6

* Mon Dec  1 2008 Cole Robinson <crobinso@redhat.com> - 0.6.0-5.fc10
- Fix spec for building on F9
- Update 'New VM' virt descriptions to be less black and white (bz 470563)

* Sun Nov 30 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 0.6.0-4
- Rebuild for Python 2.6

* Mon Oct 27 2008 Cole Robinson <crobinso@redhat.com> - 0.6.0-3.fc10
- Add dbus-x11 to Requires (bug 467886)
- Fedora translation updates (bug 467808)
- Don't add multiple sound devices if install fails
- Only popup volume path copy option on right click
- Fix a variable typo

* Tue Oct 14 2008 Cole Robinson <crobinso@redhat.com> - 0.6.0-2.fc10
- Add gnome-python2-gnome requirement.
- Allow seeing connection details if disconnected.
- Updated catalan translation.
- Update dutch translation.
- Update german translation. (bug 438136)
- Fix showing domain console when connecting to hypervisor.
- Update POTFILES to reflect reality (bug 466835)

* Wed Sep 10 2008 Cole Robinson <crobinso@redhat.com> - 0.6.0-1.fc10
- Update to 0.6.0 release
- Add libvirt storage management support
- Basic support for remote guest installation
- Merge VM console and details windows
- Poll avahi for libvirtd advertisement
- Hypervisor autoconnect option
- Add sound emulation when creating new guests

* Thu Apr  3 2008 Daniel P. Berrange <berrange@redhat.com> - 0.5.4-3.fc9
- Updated sr, de, fi, it, pl translations

* Thu Mar 13 2008 Daniel P. Berrange <berrange@redhat.com> - 0.5.4-2.fc9
- Don't run policykit checks when root (rhbz #436994)

* Mon Mar 10 2008 Daniel P. Berrange <berrange@redhat.com> - 0.5.4-1.fc9
- Update to 0.5.4 release

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.5.3-2
- Autorebuild for GCC 4.3

* Thu Jan 10 2008 Daniel P. Berrange <berrange@redhat.com> - 0.5.3-1.fc9
- Update to 0.5.3 release

* Mon Oct 15 2007 Daniel P. Berrange <berrange@redhat.com> - 0.5.2-2.fc8
- Change TLS x509 credential name to sync with libvirt

* Thu Oct  4 2007 Daniel P. Berrange <berrange@redhat.com> - 0.5.2-1.fc8
- Update to 0.5.2 release
- No scrollbars for high res guest in low res host (rhbz 273181)
- Unable to remove network device (rhbz 242900)
- Fixed broken menu items (rhbz 307551)
- Require libvirt 0.3.3 to get CDROM change capability for Xen

* Tue Sep 25 2007 Daniel P. Berrange <berrange@redhat.com> - 0.5.1-1.fc8
- Updated to 0.5.1 release
- Open connections in background
- Make VNC connection retries more robust
- Allow changing of CDROM media on the fly
- Add PXE boot installation of HVM guests
- Allow tunnelling VNC over SSH

* Wed Aug 29 2007 Daniel P. Berrange <berrange@redhat.com> - 0.5.0-1.fc8
- Updated to 0.5.0 release
- Support for managing remote hosts
- Switch to use GTK-VNC for the guest console

* Fri Aug 24 2007 Daniel P. Berrange <berrange@redhat.com> - 0.4.0-3.fc8
- Remove ExcludeArch since libvirt is now available

* Wed May  9 2007 Daniel P. Berrange <berrange@redhat.com> - 0.4.0-2.fc7
- Refresh po file translations (bz 238369)
- Fixed removal of disk/network devices
- Fixed toolbar menu option state
- Fixed file dialogs & default widget states

* Mon Apr 16 2007 Daniel P. Berrange <berrange@redhat.com> - 0.4.0-1.fc7
- Support for managing virtual networks
- Ability to attach guest to virtual networks
- Automatically set VNC keymap based on local keymap
- Support for disk & network device addition/removal

* Wed Mar 28 2007 Daniel P. Berrange <berrange@redhat.com> - 0.3.2-3.fc7
- Fix HVM check to allow KVM guests to be created (bz 233644)
- Fix default file size suggestion

* Tue Mar 27 2007 Daniel P. Berrange <berrange@redhat.com> - 0.3.2-2.fc7
- Ensure we own all directories we create (bz 233816)

* Tue Mar 20 2007 Daniel P. Berrange <berrange@redhat.com> - 0.3.2-1.fc7
- Added online help to all windows
- Bug fixes to virtual console popup, key grab & accelerator override

* Tue Mar 13 2007 Daniel P. Berrange <berrange@redhat.com> - 0.3.1-4.fc7
- Fixed thread locking to avoid deadlocks when a11y is enabled

* Fri Mar  2 2007 Daniel P. Berrange <berrange@redhat.com> - 0.3.1-3.fc7
- Fixed keyboard ungrab in VNC widget

* Tue Feb 20 2007 Daniel P. Berrange <berrange@redhat.com> - 0.3.1-2.fc7
- Only check for HVM on Xen hypervisor

* Tue Feb 20 2007 Daniel P. Berrange <berrange@redhat.com> - 0.3.1-1.fc7
- Added support for managing QEMU domains
- Automatically grab mouse pointer to workaround dual-cursor crazyness

* Wed Jan 31 2007 Daniel P. Berrange <berrange@redhat.com> - 0.3.0-2.fc7
- Added dep on desktop-file-utils for post/postun scripts

* Mon Jan 22 2007 Daniel P. Berrange <berrange@redhat.com> - 0.3.0-1.fc7
- Added support for managing inactive domains
- Require virt-inst >= 0.100.0 and libvirt >= 0.1.11 for ianctive
  domain management capabilities
- Add progress bars during VM creation stage
- Improved reliability of VNC console
- Updated translations again
- Added destroy option to menu bar to forceably kill a guest
- Visually differentiate allocated memory, from actual used memory on host
- Validate file magic when restoring a guest from a savd file
- Performance work on domain listing
- Allow creation of non-sparse files
- Fix backspace key in serial console

* Tue Dec 19 2006 Daniel P. Berrange <berrange@redhat.com> - 0.2.6-3.fc7
- Imported latest translations from Fedora i18n repository (bz 203783)
- Use 127.0.0.1 address for connecting to VNC console instead of
  localhost to avoid some issue with messed up /etc/hosts.
- Add selector for sparse or non-sparse file, defaulting to non-sparse.
  Add appropriate warnings and progress-bar text. (bz 218996)
- Disable memory ballooning & CPU hotplug for HVM guests (bz 214432)
- Updated memory-setting UI to include a hard upper limit for physical
  host RAM
- Added documentation on the page warning that setting virtual host RAM
  too high can exhaust the memory of the machine
- Handle errors when hostname resolution fails to avoid app exiting (bz 216975)

* Thu Dec  7 2006 Jeremy Katz <katzj@redhat.com> - 0.2.6-2.fc7
- rebuild for python 2.5

* Thu Nov  9 2006 Daniel P. Berrange <berrange@redhat.com> - 0.2.6-1.fc7
- Imported translations from Fedora i18n repository
- Make (most) scrollbar policies automatic
- Set busy cursor while creating new VMs
- Preference for controlling keygrab policy
- Preference for when to automatically open console (bz 211385)
- Re-try VNC connection attempt periodically in case VNC daemon
  hasn't finished starting up
- Added activation of URLs for about dialog (bz 210782)
- Improved error reporting when connecting to HV (bz 211229)
- Add command line args to open specific windows
- Don't skip para/full virt wizard step - instead gray out full
  virt option & tell user why
- Change 'physical' to 'logical' when refering to host CPUs
- Include hostname in titlebar
- Disable wizard sensitivity while creating VM

* Thu Oct 19 2006 Daniel P. Berrange <berrange@redhat.com> - 0.2.5-1.fc7
- Switch to use python-virtinst instead of python-xeninst due to 
  renaming of original package
- Disable keyboard accelerators when grabbing mouse to avoid things like
  Ctrl-W closing the local window, instead of remote window bz 210364
- Fix host memory reporting bz 211281
- Remove duplicate application menu entry bz 211230
- Fix duplicated mnemonics (bz 208408)
- Use blktap backed disks if available
- Use a drop down list to remember past URLs (bz 209479)
- Remove unused help button from preferences dialog (bz 209251)
- Fix exception when no VNC graphics is defined
- Force immediate refresh of VMs after creating a new one
- Improve error reporting if run on a kernel without Xen (bz 209122)
- More fixes to avoid stuck modifier keys on focus-out (bz 207949)

* Fri Sep 29 2006 Daniel P. Berrange <berrange@redhat.com> 0.2.3-2.fc6
- Fix segv in sparkline code when no data points are defined (bz  208185)
- Clamp CPU utilization between 0 & 100% just in case (bz 208185)

* Tue Sep 26 2006 Daniel Berrange <berrange@redhat.com> - 0.2.3-1.fc6
- Require xeninst >= 0.93.0 to fix block backed devices
- Skip para/fully-virt step when going back in wizard if not HVM host (bz 207409)
- Fix handling of modifier keys in VNC console so Alt key doesn't get stuck (bz 207949)
- Allow sticky modifier keys by pressing same key 3 times in row (enables Ctrl-Alt-F1
  by doing Ctrl Ctrl Ctrl  Alt-F1)
- Improved error handling during guest creation
- Log errors with python logging, instead of to stdout
- Remove unused buttons from main domain list window
- Switch out of full screen & release key grab when closing console
- Trim sparkline CPU history graph to 40 samples max
- Constraint VCPU adjuster to only allow upto guest's max VCPU count
- Show guest's max & current VCPU count in details page
- Fix rounding of disk sizes to avoid a 1.9 GB disk being rounded down to 1 GB
- Use raw block device path to CDROM not mount point for HVM guest (bz 206965)
- Fix visibility of file size spin box (bz 206186 part 2)
- Check for GTK failing to open X11 display (bz 205938)

* Fri Sep 15 2006 Daniel Berrange <berrange@redhat.com> - 0.2.2-1.fc6
- Fix event handling in create VM wizard (bz 206660 & 206186)
- Fix close button in about dialog (bz 205943)
- Refresh .pot files
- Turn on VNC scrollbars fulltime to avoid GTK window sizing issue
  which consistently resize too small.

* Mon Sep 11 2006 Daniel Berrange <berrange@redhat.com> - 0.2.1-3.fc6
- Added requires on pygtk2-libglade & librsvg2 (bz 205941 & 205942)
- Re-arrange to use console-helper to launch app
- Added 'dist' component to release number

* Wed Sep  6 2006 Jeremy Katz <katzj@redhat.com> - 0.2.1-2
- don't ghost pyo files (#205448)

* Mon Sep  4 2006 Daniel Berrange <berrange@redhat.com> - 0.2.1-1
- Updated to 0.2.1 tar.gz
- Added rules to install/uninstall gconf schemas in preun,post,pre
  scriptlets
- Updated URL for source to reflect new upstream download URL

* Thu Aug 24 2006 Jeremy Katz <katzj@redhat.com> - 0.2.0-3
- BR gettext

* Thu Aug 24 2006 Jeremy Katz <katzj@redhat.com> - 0.2.0-2
- only build on arches with virt

* Tue Aug 22 2006 Daniel Berrange <berrange@redhat.com> - 0.2.0-1
- Added wizard for creating virtual machines
- Added embedded serial console
- Added ability to take screenshots

* Mon Jul 24 2006 Daniel Berrange <berrange@redhat.com> - 0.1.5-2
- Prefix *.pyo files with 'ghost' macro
- Use fully qualified URL in Source  tag

* Thu Jul 20 2006 Daniel Berrange <berrange@redhat.com> - 0.1.5-1
- Update to new 0.1.5 release snapshot

* Thu Jul 20 2006 Daniel Berrange <berrange@redhat.com> - 0.1.4-1
- Update to new 0.1.4 release snapshot

* Mon Jul 17 2006 Daniel Berrange <berrange@redhat.com> - 0.1.3-1
- Fix License tag
- Updated for new release

* Wed Jun 28 2006 Daniel Berrange <berrange@redhat.com> - 0.1.2-3
- Added missing copyright headers on all .py files

* Wed Jun 28 2006 Daniel Berrange <berrange@redhat.com> - 0.1.2-2
- Added python-devel to BuildRequires

* Wed Jun 28 2006 Daniel Berrange <berrange@redhat.com> - 0.1.2-1
- Change URL to public location

* Fri Jun 16 2006 Daniel Berrange <berrange@redhat.com> - 0.1.0-1
- Added initial support for using VNC console

* Thu Apr 20 2006 Daniel Berrange <berrange@redhat.com> - 0.0.2-1
- Added DBus remote control service

* Wed Mar 29 2006 Daniel Berrange <berrange@redhat.com> - 0.0.1-1
- Initial RPM build
